@@ -465,7 +465,6 @@ estimate_size_callback (const gchar      *rel_path,
 {
 	EstimateSizeCallbackData *cb_data = data;
 
-	g_message ("info->mime_type %s", info->mime_type);
 	if (cb_data->only_isos == TRUE
 	    && info->mime_type != NULL
 	    && strcmp (info->mime_type, "application/x-cd-image") != 0)
@@ -958,7 +957,7 @@ init_dialog (GladeXML        *xml,
 	label = glade_xml_get_widget (xml, "size_label");
 
 	size_mb = (size + 1024 * 1024 - 1)/ (1024 * 1024);
-	str = g_strdup_printf (_("%d MB"), size_mb);
+	str = g_strdup_printf (_("%d MiB"), size_mb);
 	gtk_label_set_markup (GTK_LABEL (label), str);
 	g_free (str);
 
@@ -1166,8 +1165,9 @@ main (int argc, char *argv[])
 
 		if (only_isos == TRUE && size != 0) {
 			dialog = ncb_hig_dialog (GTK_MESSAGE_QUESTION,
-					_("It looks like the disc then created will only contain CD images."),
-					_("Do you really want to write those to the disc?"), NULL);
+						 _("Create disc containing only CD images?"),
+						 _("It appears that the disc, when created, will contain only CD images.  "
+						   "Do you want to continue and write those to the disc?"), NULL);
 			gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 						GTK_STOCK_QUIT, GTK_RESPONSE_NO,
 						_("Continue"), GTK_RESPONSE_YES,
